==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/models/product_image_spec.rb <==
# -*- coding: utf-8 -*-
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe ProductImage do
  fixtures :products, :product_images
  
  before(:each) do
    @valid_attributes = {
      :product_id => 1,
      :display_order => 1,
      :parent_id => 1,
      :thumbnail => "value for thumbnail",
      :filename => "value for filename",
      :content_type => "image/jpeg",
      :size => 1,
      :width => 1,
      :height => 1
    }
  end

  it "should create a new instance given valid attributes" do
    ProductImage.create!(@valid_attributes)
  end

  describe "表示順の更新" do
    before(:each) do
      ProductImage.create!(:product_id => 1, :filename => "image1", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:product_id => 1, :filename => "image2", :display_order => 2, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:product_id => 1, :filename => "image3", :display_order => 3, :content_type => "image/jpeg", :size => 777)
    end
  
    it "新しく商品画像を追加した場合は、表示順は一番最後に追加される" do
      ProductImage.create!(:product_id => 1, :filename => "image4", :content_type => "image/jpeg", :size => 777)
 
      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image2").display_order.should == 2
      ProductImage.find_by_filename("image3").display_order.should == 3
      ProductImage.find_by_filename("image4").display_order.should == 4
    end

    it "商品画像を削除した場合に、表示順が更新される" do
      image_2 = ProductImage.find_by_filename("image2")
      image_2.destroy
      image_2.update_same_product_id_images

      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image3").display_order.should == 2
    end

    it "商品画像を削除した場合に、表示順とメイン画像が更新される" do
      image_2 = ProductImage.find_by_filename("image2")
      image_2.main_flg = true
      image_2.update_same_product_id_images

      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image1").main_flg.should be_true
      ProductImage.find_by_filename("image3").display_order.should == 2
      ProductImage.find_by_filename("image3").main_flg.should_not be_true
    end
  end

  describe "public_filename" do
    it "valid" do
      product_image = ProductImage.find(1)
      product_image.filename.should == "product00001.gif"
      product_image.public_filename.should == "/ec_rider/product_images/0000/0001/product00001.gif"
      product_image.public_filename(:small).should == "/ec_rider/product_images/0000/0001/product00001_small.gif"

    end
  end


end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/models/product_image_spec.rb <==
# -*- coding: utf-8 -*-
require File.expand_path(File.dirname(__FILE__) + '/../spec_helper')

describe ProductImage do
  fixtures :products, :product_images
  
  before(:each) do
    @valid_attributes = {
      :product_id => 1,
      :display_order => 1,
      :parent_id => 1,
      :thumbnail => "thumbnail",
      :filename => "value for filename",
      :content_type => "image/jpeg",
      :size => 1,
      :width => 1,
      :height => 1
    }
  end

  it "should create a new instance given valid attributes" do
    ProductImage.create!(@valid_attributes)
  end

  describe "表示順の更新" do
    before(:each) do
      ProductImage.create!(:product_id => 1, :filename => "image1", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:product_id => 1, :filename => "image2", :display_order => 2, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:product_id => 1, :filename => "image3", :display_order => 3, :content_type => "image/jpeg", :size => 777)
    end
  
    it "新しく商品画像を追加した場合は、表示順は一番最後に追加される" do
      ProductImage.create!(:product_id => 1, :filename => "image4", :content_type => "image/jpeg", :size => 777)
 
      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image2").display_order.should == 2
      ProductImage.find_by_filename("image3").display_order.should == 3
      ProductImage.find_by_filename("image4").display_order.should == 4
    end

    it "商品画像を削除した場合に、表示順が更新される" do
      image_2 = ProductImage.find_by_filename("image2")
      image_2.destroy
      image_2.update_same_product_id_images

      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image3").display_order.should == 2
    end

    it "商品画像を削除した場合に、表示順とメイン画像が更新される" do
      image_2 = ProductImage.find_by_filename("image2")
      image_2.main_flg = true
      image_2.update_same_product_id_images

      ProductImage.find_by_filename("image1").display_order.should == 1
      ProductImage.find_by_filename("image1").main_flg.should be_true
      ProductImage.find_by_filename("image3").display_order.should == 2
      ProductImage.find_by_filename("image3").main_flg.should_not be_true
    end
  end

  describe "public_filename" do
    it "valid" do
      product_image = ProductImage.find(1)
      product_image.filename.should == "product00001.gif"
      product_image.public_filename.should == "/ec_rider/product_images/0000/0001/product00001.gif"
      product_image.public_filename(:small).should == "/ec_rider/product_images/0000/0001/product00001_small.gif"

    end
  end


  describe "create_thumbnails" do
    it "create" do
      img = ProductImage.create!(:product_id => 1, :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      img.create_thumbnails('public/cms/logo.GIF')
      ProductImage.count(:conditions=>["parent_id=?",img.id]).should == 4
    end

    it "update" do
      img = ProductImage.create!(:product_id => 2, :thumbnail=>"", :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:parent_id=>img.id, :thumbnail=>"medium", :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:parent_id=>img.id, :thumbnail=>"thumb", :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:parent_id=>img.id, :thumbnail=>"large", :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      ProductImage.create!(:parent_id=>img.id, :thumbnail=>"small", :filename => "logo.GIF", :display_order => 1, :content_type => "image/jpeg", :size => 777)
      img.create_thumbnails('public/cms/logo.GIF')
      ProductImage.count(:conditions=>["parent_id=?",img.id]).should == 4
    end
  end

end
